======
Filter
======

Filter commands are used to create real-time filters of output request data.

Create filters
--------------

In Mdb
~~~~~~

.. autoclass:: abaqus.Filter.FilterModel.FilterModel
    :members:
    :special-members: __init__

    .. autoclasstoc::

In Odb
~~~~~~

.. autoclass:: abaqus.Filter.FilterOdb.FilterOdb
    :members:
    :special-members: __init__

    .. autoclasstoc::


Classes
-------

Filter
~~~~~~

.. autoclass:: abaqus.Filter.Filter.Filter
    :members:
    :special-members: __init__

    .. autoclasstoc::

ButterworthFilter
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Filter.ButterworthFilter.ButterworthFilter
    :members:
    :special-members: __init__

    .. autoclasstoc::

Chebyshev1Filter
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Filter.Chebyshev1Filter.Chebyshev1Filter
    :members:
    :special-members: __init__

    .. autoclasstoc::

Chebyshev2Filter
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Filter.Chebyshev2Filter.Chebyshev2Filter
    :members:
    :special-members: __init__

    .. autoclasstoc::

OperatorFilter
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Filter.OperatorFilter.OperatorFilter
    :members:
    :special-members: __init__

    .. autoclasstoc::

